@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # Copyright (C) 2019-2020 All rights reserved.
 # FILENAME:  load_config.py
-# VERSION: 	 0.2.1
+# VERSION: 	 0.2.2
 # CREATED: 	 2020-11-25 14:35
 # AUTHOR: 	 Aekasitt Guruvanich <aekazitt@gmail.com>
 # DESCRIPTION:
@@ -24,7 +24,7 @@ class LoadConfig(BaseModel):
   cookie_path: Optional[StrictStr]               = '/'
   cookie_domain: Optional[StrictStr]             = None
   cookie_secure: Optional[StrictBool]            = False
-  cookie_samesite: Optional[StrictStr]           = 'none'
+  cookie_samesite: Optional[StrictStr]           = 'lax'
   cookie_csrf_protect: Optional[StrictBool]      = True
   httponly: Optional[StrictBool]                 = True
 
@@ -34,8 +34,10 @@ class LoadConfig(BaseModel):
       raise ValueError('The "csrf_methods" must be between http request methods')
     return value.upper()
 
-  @validator('cookie_samesite')
-  def validate_cookie_samesite(cls, value):
+  @validator('cookie_samesite', always=True)
+  def validate_cookie_samesite(cls, value: str, values: dict):
     if value not in { 'strict', 'lax', 'none' }:
       raise ValueError('The "cookie_samesite" must be between "strict", "lax", or "none".')
+    elif value == 'none' and values.get('cookie_secure', False) is not True:
+      raise ValueError('The "cookie_secure" must be True if "cookie_samesite" set to "none".')
     return value
